==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/client/content/equipment/armor/CardboardArmorHandlerClient.java <==
package com.zurrtum.create.client.content.equipment.armor;

import com.google.common.cache.Cache;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.content.logistics.box.PackageRenderer;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.equipment.armor.CardboardArmorHandler;
import com.zurrtum.create.foundation.utility.TickBasedCache;
import java.util.Random;
import java.util.concurrent.ExecutionException;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_243;
import net.minecraft.class_3532;
import net.minecraft.class_4050;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_742;

public class CardboardArmorHandlerClient {
    private static final Cache<Integer, Integer> BOXES_PLAYERS_ARE_HIDING_AS = new TickBasedCache<>(20, true);
    private static final Random RANDOM = new Random();

    public static void keepCacheAliveDesignDespiteNotRendering(class_742 player) {
        if (!CardboardArmorHandler.testForStealth(player))
            return;
        try {
            getCurrentBoxIndex(player.method_5628());
        } catch (ExecutionException e) {
            e.printStackTrace();
        }
    }

    public static boolean playerRendersAsBoxWhenSneaking(
        class_1007 renderer,
        class_10055 state,
        class_4587 ms,
        class_4597 vertexConsumerProvider,
        int light
    ) {
        if (state.field_53465 != class_4050.field_18081 || !CardboardArmorHandler.isCardboardArmor(state.field_55309) || !CardboardArmorHandler.isCardboardArmor(
            state.field_53418) || !CardboardArmorHandler.isCardboardArmor(state.field_53419) || !CardboardArmorHandler.isCardboardArmor(
            state.field_53420)) {
            return false;
        }

        CardboardRenderState renderState = (CardboardRenderState) state;
        if (renderState.create$isFlying())
            return false;

        if (renderState.create$isSkip())
            return true;

        ms.method_22903();

        class_243 renderOffset = renderer.method_23206(state);
        ms.method_22904(0, -renderOffset.field_1351, 0);

        if (renderState.create$isOnGround()) {
            ms.method_22904(
                0, Math.min(
                    Math.abs(class_3532.method_15362((AnimationTickHolder.getRenderTime() % 256) / 2.0f)) * -renderOffset.field_1351,
                    renderState.create$getMovement() * 5
                ), 0
            );
        }

        float scale = state.field_53453;
        ms.method_22905(scale, scale, scale);

        try {
            PartialModel model = AllPartialModels.PACKAGES_TO_HIDE_AS.get(getCurrentBoxIndex(state.field_53528));
            PackageRenderer.renderBox(state.field_53528, renderState.create$getInterpolatedYaw(), ms, vertexConsumerProvider, light, model);
        } catch (ExecutionException e) {
            e.printStackTrace();
        }

        ms.method_22909();
        return true;
    }

    private static Integer getCurrentBoxIndex(int id) throws ExecutionException {
        return BOXES_PLAYERS_ARE_HIDING_AS.get(id, () -> RANDOM.nextInt(AllPartialModels.PACKAGES_TO_HIDE_AS.size()));
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/content/equipment/armor/CardboardArmorHandlerClient.java <==
package com.zurrtum.create.client.content.equipment.armor;

import com.google.common.cache.Cache;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.content.logistics.box.PackageRenderer;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.equipment.armor.CardboardArmorHandler;
import com.zurrtum.create.foundation.utility.TickBasedCache;

import java.util.Random;
import java.util.concurrent.ExecutionException;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_11659;
import net.minecraft.class_243;
import net.minecraft.class_3532;
import net.minecraft.class_4050;
import net.minecraft.class_4587;
import net.minecraft.class_742;

public class CardboardArmorHandlerClient {
    private static final Cache<Integer, Integer> BOXES_PLAYERS_ARE_HIDING_AS = new TickBasedCache<>(20, true);
    private static final Random RANDOM = new Random();

    public static void keepCacheAliveDesignDespiteNotRendering(class_742 player) {
        if (!CardboardArmorHandler.testForStealth(player))
            return;
        try {
            getCurrentBoxIndex(player.method_5628());
        } catch (ExecutionException e) {
            e.printStackTrace();
        }
    }

    public static boolean playerRendersAsBoxWhenSneaking(
        class_1007<?> renderer,
        class_10055 state,
        class_4587 ms,
        class_11659 queue
    ) {
        if (state.field_53465 != class_4050.field_18081 || !CardboardArmorHandler.isCardboardArmor(state.field_55309) || !CardboardArmorHandler.isCardboardArmor(
            state.field_53418) || !CardboardArmorHandler.isCardboardArmor(state.field_53419) || !CardboardArmorHandler.isCardboardArmor(state.field_53420)) {
            return false;
        }

        CardboardRenderState renderState = (CardboardRenderState) state;
        if (renderState.create$isFlying())
            return false;

        if (renderState.create$isSkip())
            return true;

        ms.method_22903();

        class_243 renderOffset = renderer.method_23206(state);
        ms.method_22904(0, -renderOffset.field_1351, 0);

        if (renderState.create$isOnGround()) {
            ms.method_22904(
                0,
                Math.min(
                    Math.abs(class_3532.method_15362((AnimationTickHolder.getRenderTime() % 256) / 2.0f)) * -renderOffset.field_1351,
                    renderState.create$getMovement() * 5
                ),
                0
            );
        }

        float scale = state.field_53453;
        ms.method_22905(scale, scale, scale);

        try {
            PartialModel model = AllPartialModels.PACKAGES_TO_HIDE_AS.get(getCurrentBoxIndex(state.field_53528));
            if (model != null) {
                PackageRenderer.getBoxRenderState(state.field_53528, renderState.create$getInterpolatedYaw(), state.field_61820, model).render(ms, queue);
            }
        } catch (ExecutionException e) {
            e.printStackTrace();
        }

        ms.method_22909();
        return true;
    }

    private static Integer getCurrentBoxIndex(int id) throws ExecutionException {
        return BOXES_PLAYERS_ARE_HIDING_AS.get(id, () -> RANDOM.nextInt(AllPartialModels.PACKAGES_TO_HIDE_AS.size()));
    }
}
